@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
-
 """
-internetarchive library
+Internetarchive Library
 ~~~~~~~~~~~~~~~~~~~~~~~
 
 Internetarchive is a python interface to archive.org.
@@ -12,16 +11,13 @@ usage:
     >>> item.exists
     True
 
-See the README file for the full documentation, avilable at 
-<https://github.com/jjjake/ia-wrapper>.
-
 :copyright: (c) 2013 by Jacob M. Johnson.
 :license: GPL, see LICENSE for more details.
 
 """
 
 __title__ = 'internetarchive'
-__version__ = '0.3.3'
+__version__ = '0.3.4'
 __author__ = 'Jacob M. Johnson'
 __license__ = 'GPL'
 __copyright__ = 'Copyright 2013 Jacob M. Johnson'
