@@ -21,28 +21,43 @@ from . import __version__, ias3, config
 #_________________________________________________________________________________________
 class Item(object):
     """This class represents an archive.org item. You can use this 
-    class to access item metadata:   
+    class to access item metadata::
 
-    >>> import internetarchive
-    >>> item = internetarchive.Item('stairs')
-    >>> print item.metadata
+        >>> import internetarchive
+        >>> item = internetarchive.Item('stairs')
+        >>> print item.metadata
 
     This class also uses IA's S3-like interface to upload files to an 
     item. You need to supply your IAS3 credentials in environment 
-    variables in order to upload. You can retrieve S3 keys from:
-    https://archive.org/account/s3.php
+    variables in order to upload::
 
-    >>> import os
-    >>> os.environ['AWS_ACCESS_KEY_ID']='$access_key'
-    >>> os.environ['AWS_SECRET_ACCESS_KEY']='$secret_key'
-    >>> item.upload('myfile.tar')
-    True
+        >>> import os
+        >>> os.environ['AWS_ACCESS_KEY_ID'] = 'Y6oUrAcCEs4sK8ey'
+        >>> os.environ['AWS_SECRET_ACCESS_KEY'] = 'youRSECRETKEYzZzZ'
+        >>> item.upload('myfile.tar')
+        True
+
+    You can retrieve S3 keys here: `https://archive.org/account/s3.php 
+    <https://archive.org/account/s3.php>`__
 
     """
 
     # init()
     #_____________________________________________________________________________________
     def __init__(self, identifier, metadata_timeout=None, host=None):
+        """
+        :type identifier: str
+        :param identifier: The globally unique Archive.org identifier
+                           for a given item.
+
+        :type metadata_timeout: int
+        :param metadata_timeout: (optional) Set a timeout for 
+                                 retrieving an item's metadata.
+
+        :type host: str
+        :param host: (optional) 
+
+        """
         self.identifier = identifier
         if host:
             _url_prefix = 'https://{0}.'.format(host)
@@ -64,6 +79,13 @@ class Item(object):
     # _get_item_metadata()
     #_____________________________________________________________________________________
     def _get_item_metadata(self):
+        """Get an item's metadata from the `Metadata API 
+        <http://blog.archive.org/2013/07/04/metadata-api/>`__
+
+        :rtype: dict
+        :returns: Metadat API response.
+
+        """
         f = urllib2.urlopen(self.metadata_url, timeout=self.metadata_timeout)
         return json.loads(f.read())
 
@@ -71,7 +93,13 @@ class Item(object):
     # files()
     #_____________________________________________________________________________________
     def files(self):
-        """Generator for iterating over files in an item"""
+        """Generator for iterating over files in an item.
+
+        :rtype: generator
+        :returns: A generator that yields :class:`internetarchive.File 
+                  <File>` objects.
+
+        """
         for file_dict in self.metadata.get('files', []):
             file = File(self, file_dict)
             yield file
@@ -80,13 +108,15 @@ class Item(object):
     # file()
     #_____________________________________________________________________________________
     def file(self, name):
-        """Return an archive.org File object for the named file.
-        If the specified file was not found in the item, return None
+        """Get a :class:`File <File>` object for the named file.
+
+        :rtype: :class:`internetarchive.File <File>`
+        :returns: An :class:`internetarchive.File <File>`
+
         """
         for file_dict in self.metadata['files']:
             if file_dict['name'] == name:
                 return File(self, file_dict)
-        return None
 
 
     # download()
@@ -138,14 +168,11 @@ class Item(object):
     # modify_metadata()
     #_____________________________________________________________________________________
     def modify_metadata(self, metadata, target='metadata'):
-        """function for modifying the metadata of an existing item on 
-        archive.org.
+        """Modify the metadata of an existing item on Archive.org.
 
         Note: The Metadata Write API does not yet comply with the 
-        latest Json-Patch standard. It currently complies with version 
-        02:
-
-        https://tools.ietf.org/html/draft-ietf-appsawg-json-patch-02
+        latest Json-Patch standard. It currently complies with `version 02 
+        <https://tools.ietf.org/html/draft-ietf-appsawg-json-patch-02>`__.
 
         :type metadata: dict
         :param metadata: Metadata used to update the item.
@@ -160,6 +187,10 @@ class Item(object):
         >>> md = dict(new_key='new_value', foo=['bar', 'bar2'])
         >>> item.modify_metadata(md)
 
+        :rtype: dict
+        :returns: A dictionary containing the status_code and response
+                  returned from the Metadata API.
+
         """
         access_key, secret_key = config.get_s3_keys()
         src = self.metadata.get(target, {})
@@ -253,6 +284,11 @@ class Item(object):
             >>> item.upload_file('/path/to/image.jpg', 
             ...                  remote_name='photos/image1.jpg')
             True
+
+        :rtype: bool
+        :returns: True if the request was successful and file was 
+                  uploaded, False otherwise.
+
         """
 
         headers = ias3.get_headers(headers, metadata)
@@ -319,6 +355,12 @@ class Item(object):
             >>> md = dict(mediatype='image', creator='Jake Johnson')
             >>> item.upload('/path/to/image.jpg', md, derive=False)
             True
+        
+        :rtype: bool
+        :returns: True if the request was successful and all files were
+                  uploaded, False otherwise.
+
+        
         """
 
         if kwargs.get('debug'):
@@ -335,6 +377,7 @@ class Item(object):
 # File class
 #_________________________________________________________________________________________
 class File(object):
+    """:todo: document File class."""
 
     # init()
     #_____________________________________________________________________________________
@@ -385,6 +428,7 @@ class Search(object):
         >>> search = internetarchive.Search('(uploader:jake@archive.org)')
         >>> for result in search.results:
         ...     print result['identifier']
+
     """
 
     # init()
@@ -436,11 +480,16 @@ class Search(object):
 # Mine class
 #_________________________________________________________________________________________
 class Mine(object):
-    """
+    """This class is for concurrently retrieving metadata for items on
+    Archive.org.
+
     Usage::
+
+        >>> import internetarchive
         >>> miner = internetarchive.Mine('itemlist.txt', workers=50)
         >>> for md in miner:
         ...     print md
+
     """
     # __init__()
     #_____________________________________________________________________________________
@@ -525,6 +574,7 @@ class Mine(object):
 
 #_________________________________________________________________________________________
 class Catalog(object):
+    """:todo: Document Catalog Class."""
     GREEN = 0
     BLUE = 1
     RED = 2
